<?php

declare(strict_types=1);

namespace Drupal\Tests\ui_patterns\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\ui_patterns\Plugin\UiPatterns\PropType\UrlPropType;

/**
 * @coversDefaultClass \Drupal\ui_patterns\Plugin\UiPatterns\PropType\UrlPropType
 *
 * @group ui_patterns
 */
final class UrlPropTypeNormalizationTest extends UnitTestCase {

  /**
   * @covers ::normalize
   *
   * @dataProvider provideNormalizationData
   */
  public function testNormalize(mixed $value, string $expected): void {
    $normalized = UrlPropType::normalize($value);
    self::assertEquals($normalized, $expected);
  }

  /**
   * Provide data for testNormalize.
   */
  public static function provideNormalizationData(): \Generator {
    $data = self::notAnUrl() + self::validUrl();
    foreach ($data as $label => $test) {
      yield $label => [
        $test['value'],
        $test['expected'],
      ];
    };
  }

  /**
   * Not an URL.
   */
  protected static function notAnUrl() {
    return [
      "Empty string" => [
        "value" => "",
        "expected" => "",
      ],
      "Boolean" => [
        "value" => TRUE,
        "expected" => "",
      ],
      "Integer" => [
        "value" => 3,
        "expected" => "",
      ],
      "Array" => [
        "value" => [],
        "expected" => "",
      ],
    ];
  }

  /**
   * Valid URL.
   */
  protected static function validUrl() {
    return [
      "HTTP URL (domain only)" => [
        "value" => "http://www.foo.com",
        "expected" => "http://www.foo.com",
      ],
      "HTTP URL" => [
        "value" => "http://www.foo.com/path/to",
        "expected" => "http://www.foo.com/path/to",
      ],
      "HTTPS URL" => [
        "value" => "https://www.foo.com/path/to",
        "expected" => "https://www.foo.com/path/to",
      ],
      "HTTP(S) URL" => [
        "value" => "//www.foo.com/path/to",
        "expected" => "//www.foo.com/path/to",
      ],
      "SFTP URL" => [
        "value" => "sftp://www.foo.com/path/to",
        "expected" => "sftp://www.foo.com/path/to",
      ],
      "Full path" => [
        "value" => "/path/to",
        "expected" => "/path/to",
      ],
      "Relative path" => [
        "value" => "path/to",
        "expected" => "path/to",
      ],
      "HTTPS IRI" => [
        "value" => "https://en.tranché.org/bien-sûr",
        "expected" => "https://en.tranché.org/bien-sûr",
      ],
      "HTTPS IRI percent encoded" => [
        "value" => "https://en.wiktionary.org/wiki/%E1%BF%AC%CF%8C%CE%B4%CE%BF%CF%82",
        "expected" => "https://en.wiktionary.org/wiki/%E1%BF%AC%CF%8C%CE%B4%CE%BF%CF%82",
      ],
    ];
  }

}
